==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>画像表示</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>振るまい</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>ダブルクリック</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>ダブルクリックでテキスト編集</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>ブロック参照をダブルクリックしてブロックをオープン</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-85"/>
        <source>Right-Click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Cursor range for snap:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Cursor range for picking entities:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/BehaviorPreferences/ts/BehaviorPreferences_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>BehaviorPreferences</name>
    <message>
        <location filename="../BehaviorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>グラフィックビュー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Behavior</source>
        <translation>振るまい</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+48"/>
        <source>Double-Click</source>
        <translation>ダブルクリック</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Double-click to edit text</source>
        <translation>ダブルクリックでテキスト編集</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click to edit hatch</source>
        <translation>ダブルクリックでハッチング修正</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Double-click on block reference opens block</source>
        <translation>ブロック参照をダブルクリックしてブロックをオープン</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Right double-click to reset</source>
        <translation>右ダブルクリックでリセット</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Blocks</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Select block references together with attributes</source>
        <translation>ブロック参照を属性と一緒に選択する</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Hide attributes when block references are hidden</source>
        <translation>参照が非表示の時に属性を隠す</translation>
    </message>
    <message>
        <location line="+126"/>
        <source>Highlight entity within range</source>
        <translation>範囲内のエンティティをハイライト</translation>
    </message>
    <message>
        <location line="-211"/>
        <source>Right-Click</source>
        <translation>右クリック</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Right-click to deselect entities</source>
        <translation>右クリックでエンティティを選択解除</translation>
    </message>
    <message>
        <location line="+46"/>
        <source>Double-click to select contour</source>
        <translation>ダブルクリックで輪郭を選択</translation>
    </message>
    <message>
        <location line="+43"/>
        <source>Cursor Range</source>
        <translation>カーソル範囲</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Cursor range for snap:</source>
        <translation>スナップするカーソル範囲:</translation>
    </message>
    <message>
        <location line="-7"/>
        <source>Cursor range for picking entities:</source>
        <translation>エンティティを拾うためにカーソルで範囲指定</translation>
    </message>
</context>
</TS>
